@@ -1,16 +1,26 @@
-import os, cgi, re
-from os.path import *
-from gettext import gettext as _
-import deskbar, deskbar.core.gnomedesktop
-import gtk, gtk.gdk, gnome.ui, gobject, gnomevfs
-from htmlentitydefs import name2codepoint
-import logging
 from deskbar.core.GconfStore import GconfStore
 from deskbar.core._userdirs import *
+from gettext import gettext as _
+from htmlentitydefs import name2codepoint
+from os.path import *
+import cgi
+import deskbar
 import deskbar.core.Categories
+import deskbar.core.gnomedesktop
+import gnome.ui
+import gnomevfs
+import gobject
+import gtk
+import gtk.gdk
+import logging
+import os
+import re
 
 LOGGER = logging.getLogger(__name__)
 
+PATH = [path for path in os.getenv("PATH").split(os.path.pathsep)
+        if path.strip() != "" and exists(path) and isdir(path)]
+
 ICON_THEME = gtk.icon_theme_get_default()
 factory = gnome.ui.ThumbnailFactory(deskbar.ICON_HEIGHT)
 
@@ -99,10 +109,10 @@ def load_icon(icon, width=deskbar.ICON_HEIGHT, height=deskbar.ICON_HEIGHT):
             elif icon.startswith("/"):
                 pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(icon, width, height)
             else:
-                pixbuf = ICON_THEME.load_icon(splitext(icon)[0], width, gtk.ICON_LOOKUP_USE_BUILTIN)
+                pixbuf = load_icon_from_icon_theme(splitext(icon)[0], width)
         except Exception, msg1:
             try:
-                pixbuf = ICON_THEME.load_icon(icon, width, gtk.ICON_LOOKUP_USE_BUILTIN)
+                pixbuf = load_icon_from_icon_theme(icon, width)
             except Exception, msg2:
                 LOGGER.warning ("Icon %s Load Error: %s (or %s)", icon, msg1, msg2)
                 pixbuf = _get_fall_back_icon()
@@ -112,25 +122,30 @@ def load_icon(icon, width=deskbar.ICON_HEIGHT, height=deskbar.ICON_HEIGHT):
         pixbuf = pixbuf.scale_simple(width, height, gtk.gdk.INTERP_BILINEAR)
     return pixbuf
 
+def load_icon_from_icon_theme(iconname, size):
+    return ICON_THEME.load_icon(iconname, size, gtk.ICON_LOOKUP_USE_BUILTIN)
+
 def _get_fall_back_icon():
     """
     @return: stock_unknown icon or C{None}
     """
     try:
-        return ICON_THEME.load_icon("stock_unknown", width, gtk.ICON_LOOKUP_USE_BUILTIN)
+        return load_icon_from_icon_theme("stock_unknown", width)
     except Exception, msg:
         LOGGER.warning ("Icon `stock_unknown' is not present in theme")
         return None
 
-PATH = [path for path in os.getenv("PATH").split(os.path.pathsep) if path.strip() != "" and exists(path) and isdir(path)]
 def is_program_in_path(program):
     """
     Whether C{program} is in PATH
     """
     for path in PATH:
         prog_path = join(path, program)
-        if exists(prog_path) and isfile(prog_path) and os.access(prog_path, os.F_OK | os.R_OK | os.X_OK):
+        if exists(prog_path) and isfile(prog_path) and is_executable(prog_path):
             return True
+        
+def is_executable(prog_path):
+    return os.access(prog_path, os.F_OK | os.R_OK | os.X_OK)
 
 def spawn_async(args):
     try:
